@@ -132,13 +132,13 @@
 #define M *1024*1024
 
 /* Some forward declarations */
-void byee();
+void byee(int exit_val);
 void start_reader_and_writer();
-void parse_args();
+void parse_args(int argc, char **argv);
 void set_handlers();
 void buffer_allocate();
 void report_proc();
-int do_size();
+int do_size(char *arg);
 void get_buffer();
 void reader();
 void writer();
@@ -149,7 +149,7 @@ void test_writer();
 int fill_block();
 void get_next_filled_block();
 int data_to_write();
-void write_blocks_to_stdout();
+void write_blocks_to_stdout(int filled, int first_block);
 void write_block_to_stdout();
 void pr_out();
 void end_writer();
@@ -833,8 +833,7 @@ write_block_to_stdout()
 
 
 void
-byee( exit_val )
-	int exit_val;
+byee( int exit_val )
 {
 	if( writer_pid != 0 ){
 		if( exit_val != 0 ){
