@@ -23,6 +23,19 @@ COMMENTAIRE :
 #include "systools.h"
 #include "dvdtools.h"
 
+/*@$#[dvdcell.c] static proto. AutoProtoSigV1.1. date: 107/12/17 23:14:24 */
+#include "proto.h"
+#ifdef __cplusplus
+extern "C" {
+#endif
+static int IsSelected PROTO((Cell_t *c, int noPisteVideo));
+static int CellExist PROTO((CellArray_t *ca, int vts, uint32_t *start, uint32_t *end));
+static void UnSelectLastCell PROTO((CellArray_t *ca));
+#ifdef __cplusplus
+}
+#endif
+/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
+
 char DbgLevels[256];
 
 
@@ -150,15 +163,26 @@ static void UnSelectLastCell( CellArray_t * ca )
 Linux!jef 2006/01/25 01:11:11
 ------------------------------------------------------------------------------*/
 
-static int CellExist( CellArray_t * ca, int vts, int startSector )
+static int CellExist( CellArray_t * ca, int vts, uint32_t * start, uint32_t * end )
 {
 	int i;
 
 	for( i = 0; i < ca->nbCells; i++ ) {
 		Cell_t * c = ca->cells + i;
 
-		if( c->vts == vts && c->startSector == startSector )	return( 1 );
+		if( c->vts == vts ) {
+			if( c->startSector <= *start && c->lastSector >= *end ) return( 1 );
+#if 0
+			if( c->startSector <= *start ) {
+				*start = c->lastSector + 1;
+			}
+			else {
+				*end = c->startSector - 1;
+			}
+#endif
+		}
 	}
+	if( *start >= *end )	return( 1 );
 	return( 0 );
 }
 
@@ -168,47 +192,65 @@ static int CellExist( CellArray_t * ca, int vts, int startSector )
 Linux!jef 2005/12/28 21:18:16
 ------------------------------------------------------------------------------*/
 
-int BuildCells( int noPisteVideo, CellArray_t * ca )
+int BuildCells( int noPisteVideo, CellArray_t * ca, int lastF )
 {
 	int nrTS = Ifo_zero->vmgi_mat->vmg_nr_of_title_sets;
 	int i,j,k;
-	DBG('b',fprintf(stderr,"%s: nrTS=%d\n", __FUNCTION__, nrTS ););
+
+	DBG('b',fprintf(stderr,"%s: nrTS=%d noPisteVideo=%d\n", __FUNCTION__, nrTS, noPisteVideo ););
 	for( k = 1; k <= nrTS; k++ ) {
 		ifo_handle_t * ifo = Ifo[k];
+		int vts_ttn, title_set_nr;
+
 		if( !ifo->vtsi_mat )	continue;
-		DBG('b',fprintf(stderr,"VTS: %d PGCS: %d\n", k, ifo->vts_pgcit->nr_of_pgci_srp ););
-		for( i = 0; i < ifo->vts_pgcit->nr_of_pgci_srp; i++ ) {
+		DBG('b',fprintf(stderr,"VTS: %d PGCS: %d ifo: %p\n", k, ifo->vts_pgcit->nr_of_pgci_srp, ifo ););
+
+		vts_ttn = Ifo_zero->tt_srpt->title[noPisteVideo].vts_ttn;
+		title_set_nr = Ifo_zero->tt_srpt->title[noPisteVideo].title_set_nr;
+
+		i = Ifo[title_set_nr]->vts_ptt_srpt->title[vts_ttn - 1].ptt[0].pgcn - 1;
+//		for( i = 0; i < ifo->vts_pgcit->nr_of_pgci_srp; i++ )
+		{
 			pgc_t * pgc = ifo->vts_pgcit->pgci_srp[i].pgc;
 			cell_playback_t * cell_playback = pgc->cell_playback;
 			int nr = pgc->nr_of_cells;
+			DBG('b',fprintf(stderr,"NrOfCells: %d\n", nr ););
 			for( j = 0; j < nr; j++ ) {
-				if( !CellExist( ca, k, cell_playback[j].first_sector ) ) {
+				uint32_t start = cell_playback[j].first_sector;
+				uint32_t end = cell_playback[j].last_sector;
+
+				if( !CellExist( ca, k, &start, &end ) ) {
 					Cell_t * c = NewCell( ca );
 
 					c->vts = k;
 					c->ifo = ifo;
 					c->pgc = pgc;
-					c->startSector = cell_playback[j].first_sector;
-					c->lastSector = cell_playback[j].last_sector;
+					c->startSector = start;
+					c->lastSector = end;
 					c->selected = IsSelected( c, noPisteVideo );
 					c->chapter = j;
 				}
 			}
 		}
 	}
+	if( lastF )	UnSelectLastCell( ca );
 
 	DBG('b',fprintf(stderr,"NrCells: %d\n", ca->nbCells );
+	long long tSize = 0;
 	for( i = 0; i < ca->nbCells; i++ ) {
 		Cell_t * c = ca->cells + i;
 		long long size;
 
 		fprintf(stderr,"Cell%d: ", i);
-		size = (long long)(c->lastSector - c->startSector) * SECTOR_SIZE;
+		size = (long long)(c->lastSector - c->startSector + 1) * SECTOR_SIZE;
+		tSize += size;
 		fprintf(stderr,"vts: %d ", c->vts );
 		fprintf(stderr,"start: %u end: %u ", c->startSector, c->lastSector );
 		fprintf(stderr,"size: %s ", LLSize2Giga( size ) );
 		fprintf(stderr,"selected: %d\n", c->selected );
-	});
+	}
+	fprintf(stderr,"Total size: %s\n", LLSize2Giga( tSize ) );
+	);
 	return( 0 );
 }
 
