@@ -84,8 +84,6 @@ COMMENTAIRE :
 #include "ac.h"
 #include "globals.h"
 
-int IgnoreErrors=-1;
-
 /* Autocorrection du requant */
 #define USE_CORRECTION_FACTOR		0
 
@@ -102,6 +100,8 @@ int IgnoreErrors=-1;
 #define VBUF_SIZE (1024*1024)
 
 
+int IgnoreErrors=1;
+
 // shortcuts for some frequently used types
 typedef unsigned char      UInt8;
 typedef unsigned long      UInt32;
@@ -195,7 +195,7 @@ pthread_cond_t  condw = PTHREAD_COND_INITIALIZER;
 pthread_mutex_t mutr  = PTHREAD_MUTEX_INITIALIZER;
 pthread_mutex_t mutw  = PTHREAD_MUTEX_INITIALIZER;
 
-/*@$#[vaporize.c] static proto. AutoProtoSigV1.1. date: 106/11/09 22:17:47 */
+/*@$#[vaporize.c] static proto. AutoProtoSigV1.1. date: 107/06/20 22:33:08 */
 #include "proto.h"
 #ifdef __cplusplus
 extern "C" {
@@ -210,6 +210,7 @@ static void read_injections PROTO((char *filename));
 static void write_injections PROTO((char *filename));
 static void usage PROTO((void));
 static void fatal PROTO((char *fmt, ...));
+static void warning PROTO((char *fmt, ...));
 #ifdef __cplusplus
 }
 #endif
@@ -465,7 +466,8 @@ Linux!jef 2006/02/20 23:04:02
 
 void VaporizePacks( int * videoPacks, int * auxPacks )
 {
-	if( videoPacks )	*videoPacks = video_packs;
+/*1.3p1	if( videoPacks )	*videoPacks = video_packs; */
+	if( videoPacks )	*videoPacks = VideoPacketSize;
 	if( auxPacks)		*auxPacks = aux_packs + nav_packs;
 }
 
@@ -599,7 +601,11 @@ check_pack (UInt8 *ptr)
 
   if (pack_start_code != 0x000001ba) {
   	if( pack_start_code == 0 && IgnoreErrors ) {
-		fprintf(stderr, "Bad pack start code at %llu: %08lx\n", rtell (ptr), pack_start_code);
+  		static int _Warn = 0;
+		if( _Warn < 1000 ) { /* Avoid too many trace */
+			fprintf(stderr, "Bad pack start code at %llu: %08lx\n", rtell (ptr), pack_start_code);
+			_Warn++;
+		}
   		return( -1 ); /* Skip it */
   	}
   	fatal ("Bad pack start code at %llu: %08lx", rtell (ptr), pack_start_code);
@@ -664,34 +670,38 @@ check_video_packet (UInt8 *ptr)
       sequence_headers++;
     }
   }
+/*  These errors seems to arrives with some old DVDs but the result is good !
+	So we just emit a warning instead of an error
+*/
+	pad_packet_length = 0;
 
-  pad_packet_length = 0;
+	if (14 + vid_packet_length < SECT_SIZE - 6) {
+// video packet does not fill whole sector
+// check for padding packet
+		ptr += vid_packet_length;
 
-  if (14 + vid_packet_length < SECT_SIZE - 6)
-  {
-    // video packet does not fill whole sector
-    // check for padding packet
-    ptr += vid_packet_length;
+		pad_packet_start_code  = (UInt32) (ptr [0]) << 24;
+	pad_packet_start_code |= (UInt32) (ptr [1]) << 16;
+	pad_packet_start_code |= (UInt32) (ptr [2]) <<  8;
+	pad_packet_start_code |= (UInt32) (ptr [3]);
 
-    pad_packet_start_code  = (UInt32) (ptr [0]) << 24;
-    pad_packet_start_code |= (UInt32) (ptr [1]) << 16;
-    pad_packet_start_code |= (UInt32) (ptr [2]) <<  8;
-    pad_packet_start_code |= (UInt32) (ptr [3]);
+	pad_packet_length  = ptr [4] << 8;
+	pad_packet_length |= ptr [5];
+	pad_packet_length += 6;
 
-    if (pad_packet_start_code != 0x000001be)
-      fatal ("Bad padding packet start code at %llu: %08lx",
-	     rtell (ptr + vid_packet_length), pad_packet_start_code);
+	if (pad_packet_start_code != 0x000001be)
+		warning("Bad padding packet start code at %llu: %08x vid_packet_length: %d pad_packet_length: %d",
+			rtell(ptr + vid_packet_length),
+			pad_packet_start_code,
+			vid_packet_length,
+			pad_packet_length );
 
-    pad_packet_length  = ptr [4] << 8;
-    pad_packet_length |= ptr [5];
-    pad_packet_length += 6;
-  }
-
-  // length of video packet plus padding packet must always match sector size
-  if (14 + vid_packet_length + pad_packet_length != SECT_SIZE)
-    fatal ("Bad video packet length at %llu: vpl=%d ppl=%d",
-	   rtell (ptr), vid_packet_length, pad_packet_length );
+	}
 
+// length of video packet plus padding packet must always match sector size
+	if( 14 + vid_packet_length + pad_packet_length != SECT_SIZE)
+		warning("Bad video packet length at %llu: vpl=%d ppl=%d",
+			rtell(ptr), vid_packet_length, pad_packet_length );
   return rc;
 }
 
@@ -927,7 +937,6 @@ vap_leader (void)
 		 rtell (ptr), data_length);
 
 	break;
-
       default:
 	fatal ("Encountered stream ID %02x at %llu, "
 	       "probably bad MPEG2 program stream", id, rtell (ptr));
@@ -979,12 +988,14 @@ vap_trailer (int length)
     }
     else
     {
+#if 000 /* 1.3p1 */
 	if( id == 0xe0 )
 		VideoPacketSize++;
 	else {
 		NavPacketSize++;
 //!!		fprintf(stderr,"%s: id 0x%x\n", __FUNCTION__, id );
 	}
+#endif
       copy (SECT_SIZE);
     }
 
@@ -1029,6 +1040,8 @@ vap_phase1 (void)
     {
       case 0xe0:
 	// video
+/*1.3p1*/
+	VideoPacketSize++;
 	seqhdr = check_video_packet (ptr);
 
 	if (seq_length)
@@ -1099,6 +1112,8 @@ vap_phase1 (void)
 
       case 0xbb:
 	// system header/private 2: PCI/DSI
+/* 1.3p1 */
+	NavPacketSize++;
 	nav_packs++;
 	break;
 
@@ -1217,7 +1232,9 @@ vap_phase2 (int seq_length)
 	  // still some video output data left
 	  voptr += gen_video_packet (ptr, voptr, avail);
 	  copy (SECT_SIZE);
+#if 0 /*1.3p0*/
 	  VideoPacketSize++;
+#endif
 	}
 	else
 	{
@@ -1469,3 +1486,18 @@ fatal (char *fmt, ...)
 }
 
 
+static void
+warning (char *fmt, ...)
+{
+	va_list ap;
+	char buffer[1024];
+
+	fprintf (stderr, "%s: Warning: ", progname);
+
+	va_start (ap, fmt);
+	vsnprintf( buffer, sizeof(buffer), fmt, ap);
+	fprintf(stderr,"%s\n", buffer );
+	va_end (ap);
+}
+
+
